@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2016 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2018 Sean Davis <smd.seandavis@gmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -19,6 +19,6 @@
 '''facade - makes catfish_lib package easy to refactor
 
 while keeping its api constant'''
-from . helpers import set_up_logging  # lint:ok
-from . Window import Window  # lint:ok
-from . catfishconfig import get_version  # lint:ok
+from . helpers import set_up_logging  # noqa
+from . Window import Window  # noqa
+from . catfishconfig import get_version  # noqa
